@@ -1,4 +1,4 @@
-# Copyright 2008-2010 Kouhei Sutou <kou@cozmixng.org>
+# Copyright 2008-2011 Kouhei Sutou <kou@cozmixng.org>
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Lesser General Public
@@ -88,7 +88,7 @@ class PackageConfig
         extern "const char *dln_find_exe(const char *, const char *)"
       end
       path = dln.dln_find_exe(pkg_config.to_s, nil)
-      if path.size.zero?
+      if path.nil? or path.size.zero?
         nil
       else
         Pathname(path.to_s)
@@ -104,6 +104,7 @@ class PackageConfig
     path = @options[:path] || ENV["PKG_CONFIG_PATH"]
     @paths = [path, guess_default_path].compact.join(SEPARATOR).split(SEPARATOR)
     @paths.unshift(*(@options[:paths] || []))
+    @paths = normalize_paths(@paths)
     @msvc_syntax = @options[:msvc_syntax]
     @variables = @declarations = nil
     override_variables = self.class.custom_override_variables
@@ -113,7 +114,7 @@ class PackageConfig
   end
 
   def exist?
-    not pc.nil?
+    not pc_path.nil?
   end
 
   def requires
@@ -126,7 +127,7 @@ class PackageConfig
 
   def cflags
     path_flags, other_flags = collect_cflags
-    (path_flags + other_flags).join(" ")
+    (other_flags + path_flags).join(" ")
   end
 
   def cflags_only_I
@@ -176,17 +177,17 @@ class PackageConfig
     expand_value(@declarations[name])
   end
 
-  private
-  def pc
+  def pc_path
     @paths.each do |path|
-      pc_name = File.join(path, "#{@name}.pc")
-      return pc_name if File.exist?(pc_name)
+      _pc_path = File.join(path, "#{@name}.pc")
+      return _pc_path if File.exist?(_pc_path)
     end
-    return nil
+    nil
   end
 
+  private
   def collect_cflags
-    all_cflags = required_packages.collect do |package|
+    all_cflags = all_required_packages.collect do |package|
       self.class.new(package, @options).cflags
     end
     all_cflags = [declaration("Cflags")] + all_cflags
@@ -233,7 +234,7 @@ class PackageConfig
     raise ".pc for #{@name} doesn't exist." unless exist?
     @variables = {}
     @declarations = {}
-    File.open(pc) do |input|
+    File.open(pc_path) do |input|
       input.each_line do |line|
         line = line.gsub(/#.*/, '').strip
         next if line.empty?
@@ -270,14 +271,14 @@ class PackageConfig
   end
 
   def guess_default_path
+    arch_depended_path = Dir.glob('/usr/lib/*/pkgconfig').join(SEPARATOR)
     default_path = ["/usr/local/lib64/pkgconfig",
                     "/usr/local/lib/pkgconfig",
                     "/usr/local/libdata/pkgconfig",
                     "/opt/local/lib/pkgconfig",
-                    "/usr/lib/pkgconfig",
+                    arch_depended_path,
                     "/usr/lib64/pkgconfig",
-                    "/usr/lib/x86_64-linux-gnu/pkgconfig",
-                    "/usr/lib/i386-linux-gnu/pkgconfig",
+                    "/usr/lib/pkgconfig",
                     "/usr/X11/lib/pkgconfig/",
                     "/usr/share/pkgconfig"].join(SEPARATOR)
     libdir = ENV["PKG_CONFIG_LIBDIR"]
@@ -285,20 +286,37 @@ class PackageConfig
 
     pkg_config = self.class.native_pkg_config
     return default_path unless pkg_config.absolute?
-    [(pkg_config.parent.parent + "lib" + "pkgconfig").to_s,
-     (pkg_config.parent.parent + "libdata" + "pkgconfig").to_s,
+    pkg_config_prefix = pkg_config.parent.parent
+    pkg_config_arch_depended_path =
+      Dir.glob((pkg_config_prefix + "lib/*/pkgconfig").to_s).join(SEPARATOR)
+    [pkg_config_arch_depended_path,
+     (pkg_config_prefix + "lib64/pkgconfig").to_s,
+     (pkg_config_prefix + "lib/pkgconfig").to_s,
+     (pkg_config_prefix + "libdata/pkgconfig").to_s,
      default_path].join(SEPARATOR)
   end
 
   def required_packages
+    requires.reject do |package|
+      @name == package
+    end.uniq
+  end
+
+  def all_required_packages
     (requires_private + requires.reverse).reject do |package|
       @name == package
     end.uniq
   end
+
+  def normalize_paths(paths)
+    paths.reject do |path|
+      path.empty? or !File.exist?(path)
+    end
+  end
 end
 
 module PKGConfig
-  VERSION = "1.1.1"
+  VERSION = "1.1.3"
 
   @@paths = []
   @@override_variables = {}
@@ -313,7 +331,7 @@ module PKGConfig
   end
 
   def msvc?
-    /mswin32/.match(RUBY_PLATFORM) and /^cl\b/.match(Config::CONFIG['CC'])
+    /mswin32/.match(RUBY_PLATFORM) and /^cl\b/.match(RbConfig::CONFIG['CC'])
   end
 
   def package_config(package)
@@ -359,9 +377,9 @@ module PKGConfig
     package_config(pkg).variable(name)
   end
 
-  def check_version?(pkg, major = 0, minor = 0, micro = 0)
+  def check_version?(pkg, major=0, minor=0, micro=0)
     return false unless exist?(pkg)
-    ver = modversion(pkg).split(".").collect{|item| item.to_i}
+    ver = modversion(pkg).split(".").collect {|item| item.to_i}
     (0..2).each {|i| ver[i] = 0 unless ver[i]}
 
     (ver[0] > major ||
@@ -370,7 +388,7 @@ module PKGConfig
       ver[2] >= micro))
   end
 
-  def have_package(pkg, major = nil, minor = 0, micro = 0)
+  def have_package(pkg, major=nil, minor=0, micro=0)
     message = "#{pkg}"
     unless major.nil?
       message << " version (>= #{major}.#{minor}.#{micro})"
