@@ -3,10 +3,12 @@
 # Author:: Nathaniel Talbott.
 # Copyright::
 #   * Copyright (c) 2000-2003 Nathaniel Talbott. All rights reserved.
-#   * Copyright (c) 2008-2009 Kouhei Sutou <kou@clear-code.com>
+#   * Copyright (c) 2008-2011 Kouhei Sutou <kou@clear-code.com>
 # License:: Ruby license.
 
 require 'test/unit/color-scheme'
+require 'test/unit/code-snippet-fetcher'
+require 'test/unit/diff'
 require 'test/unit/ui/testrunner'
 require 'test/unit/ui/testrunnermediator'
 require 'test/unit/ui/console/outputlevel'
@@ -37,13 +39,24 @@ module Test
             @progress_row = 0
             @progress_row_max = @options[:progress_row_max]
             @progress_row_max ||= guess_progress_row_max
+            @show_detail_immediately = @options[:show_detail_immediately]
+            @show_detail_immediately = true if @show_detail_immediately.nil?
             @already_outputted = false
             @indent = 0
             @top_level = true
+            @current_output_level = NORMAL
             @faults = []
+            @code_snippet_fetcher = CodeSnippetFetcher.new
           end
 
           private
+          def change_output_level(level)
+            old_output_level = @current_output_level
+            @current_output_level = level
+            yield
+            @current_output_level = old_output_level
+          end
+
           def setup_mediator
             super
             output_setup_end
@@ -56,21 +69,29 @@ module Test
           end
 
           def attach_to_mediator
-            @mediator.add_listener(TestResult::FAULT, &method(:add_fault))
-            @mediator.add_listener(TestRunnerMediator::STARTED, &method(:started))
-            @mediator.add_listener(TestRunnerMediator::FINISHED, &method(:finished))
-            @mediator.add_listener(TestCase::STARTED, &method(:test_started))
-            @mediator.add_listener(TestCase::FINISHED, &method(:test_finished))
-            @mediator.add_listener(TestSuite::STARTED, &method(:test_suite_started))
-            @mediator.add_listener(TestSuite::FINISHED, &method(:test_suite_finished))
+            @mediator.add_listener(TestResult::FAULT,
+                                   &method(:add_fault))
+            @mediator.add_listener(TestRunnerMediator::STARTED,
+                                   &method(:started))
+            @mediator.add_listener(TestRunnerMediator::FINISHED,
+                                   &method(:finished))
+            @mediator.add_listener(TestCase::STARTED_OBJECT,
+                                   &method(:test_started))
+            @mediator.add_listener(TestCase::FINISHED_OBJECT,
+                                   &method(:test_finished))
+            @mediator.add_listener(TestSuite::STARTED_OBJECT,
+                                   &method(:test_suite_started))
+            @mediator.add_listener(TestSuite::FINISHED_OBJECT,
+                                   &method(:test_suite_finished))
           end
-          
+
           def add_fault(fault)
             @faults << fault
             output_progress(fault.single_character_display, fault_color(fault))
+            output_progress_in_detail(fault) if @show_detail_immediately
             @already_outputted = true if fault.critical?
           end
-          
+
           def started(result)
             @result = result
             output_started
@@ -82,69 +103,165 @@ module Test
 
           def finished(elapsed_time)
             nl if output?(NORMAL) and !output?(VERBOSE)
-            @faults.each_with_index do |fault, index|
-              nl
-              output_single("%3d) " % (index + 1))
-              output_fault(fault)
+            output_faults unless @show_detail_immediately
+            nl(PROGRESS_ONLY)
+            change_output_level(IMPORTANT_FAULTS_ONLY) do
+              output_statistics(elapsed_time)
             end
-            nl
-            output("Finished in #{elapsed_time} seconds.")
-            nl
-            output(@result, result_color)
-            output("%g%% passed" % @result.pass_percentage, result_color)
           end
 
-          def output_fault(fault)
-            if @use_color and fault.is_a?(Failure) and
-                fault.inspected_expected and fault.inspected_actual
+          def output_faults
+            categorized_faults = categorize_faults
+            change_output_level(IMPORTANT_FAULTS_ONLY) do
+              output_faults_in_detail(categorized_faults[:need_detail_faults])
+            end
+            output_faults_in_short("Omissions", Omission,
+                                   categorized_faults[:omissions])
+            output_faults_in_short("Notifications", Notification,
+                                   categorized_faults[:notifications])
+          end
+
+          def max_digit(max_number)
+            (Math.log10(max_number) + 1).truncate
+          end
+
+          def output_faults_in_detail(faults)
+            return if faults.nil?
+            digit = max_digit(faults.size)
+            faults.each_with_index do |fault, index|
+              nl
+              output_single("%#{digit}d) " % (index + 1))
+              output_fault_in_detail(fault)
+            end
+          end
+
+          def output_faults_in_short(label, fault_class, faults)
+            return if faults.nil?
+            digit = max_digit(faults.size)
+            nl
+            output_single(label, fault_class_color(fault_class))
+            output(":")
+            faults.each_with_index do |fault, index|
+              output_single("%#{digit}d) " % (index + 1))
+              output_fault_in_short(fault)
+            end
+          end
+
+          def categorize_faults
+            faults = {}
+            @faults.each do |fault|
+              category = categorize_fault(fault)
+              faults[category] ||= []
+              faults[category] << fault
+            end
+            faults
+          end
+
+          def categorize_fault(fault)
+            case fault
+            when Omission
+              :omissions
+            when Notification
+              :notifications
+            else
+              :need_detail_faults
+            end
+          end
+
+          def output_fault_in_detail(fault)
+            if fault.is_a?(Failure)
               output_single(fault.label, fault_color(fault))
               output(":")
+              output(fault.test_name)
               output_fault_backtrace(fault)
               output_fault_message(fault)
             else
-              label, detail = format_fault(fault).split(/\r?\n/, 2)
-              output(label, fault_color(fault))
-              output(detail)
+              output_single(fault.label, fault_color(fault))
+              if fault.is_a?(Error)
+                output(": #{fault.test_name}")
+                output(fault.message)
+              else
+                output(": #{fault.message}")
+                output(fault.test_name)
+              end
+              output_fault_backtrace(fault)
             end
           end
 
           def output_fault_backtrace(fault)
+            snippet_is_shown = false
             backtrace = fault.location
-            if backtrace.size == 1
-              output(fault.test_name +
-                     backtrace[0].sub(/\A(.+:\d+).*/, ' [\\1]') +
-                     ":")
-            else
-              output(fault.test_name)
-              backtrace.each_with_index do |entry, i|
-                if i.zero?
-                  prefix = "["
-                  postfix = ""
-                elsif i == backtrace.size - 1
-                  prefix = " "
-                  postfix = "]:"
-                else
-                  prefix = " "
-                  postfix = ""
-                end
-                output("    #{prefix}#{entry}#{postfix}")
-              end
+            # workaround for test-spec. :<
+            # see also GitHub:#22
+            backtrace ||= []
+            backtrace.each_with_index do |entry, i|
+              output(entry)
+              next if snippet_is_shown
+              snippet_is_shown = output_code_snippet(entry, fault_color(fault))
             end
           end
 
+          def output_code_snippet(entry, target_line_color=nil)
+            return false unless /\A(.*):(\d+)/ =~ entry
+            file = $1
+            line_number = $2.to_i
+            lines = @code_snippet_fetcher.fetch(file, line_number)
+            return false if lines.empty?
+
+            max_n = lines.collect {|n, line, attributes| n}.max
+            digits = (Math.log10(max_n) + 1).truncate
+            lines.each do |n, line, attributes|
+              if attributes[:target_line?]
+                line_color = target_line_color
+                current_line_mark = "=>"
+              else
+                line_color = nil
+                current_line_mark = ""
+              end
+              output("  %2s %*d: %s" % [current_line_mark, digits, n, line],
+                     line_color)
+            end
+            true
+          end
+
           def output_fault_message(fault)
+            if fault.expected.respond_to?(:encoding) and
+                fault.actual.respond_to?(:encoding) and
+                fault.expected.encoding != fault.actual.encoding
+              need_encoding = true
+            else
+              need_encoding = false
+            end
             output(fault.user_message) if fault.user_message
             output_single("<")
             output_single(fault.inspected_expected, color("pass"))
-            output("> expected but was")
+            output_single(">")
+            if need_encoding
+              output_single("(")
+              output_single(fault.expected.encoding.name, color("pass"))
+              output_single(")")
+            end
+            output(" expected but was")
             output_single("<")
             output_single(fault.inspected_actual, color("failure"))
-            output(">")
+            output_single(">")
+            if need_encoding
+              output_single("(")
+              output_single(fault.actual.encoding.name, color("failure"))
+              output_single(")")
+            end
+            output("")
             from, to = prepare_for_diff(fault.expected, fault.actual)
             if from and to
-              differ = ColorizedReadableDiffer.new(from.split(/\r?\n/),
-                                                   to.split(/\r?\n/),
-                                                   self)
+              from_lines = from.split(/\r?\n/)
+              to_lines = to.split(/\r?\n/)
+              if need_encoding
+                from_lines << ""
+                to_lines << ""
+                from_lines << "Encoding: #{fault.expected.encoding.name}"
+                to_lines << "Encoding: #{fault.actual.encoding.name}"
+              end
+              differ = ColorizedReadableDiffer.new(from_lines, to_lines, self)
               if differ.need_diff?
                 output("")
                 output("diff:")
@@ -153,14 +270,37 @@ module Test
             end
           end
 
+          def output_fault_in_short(fault)
+            output_single(fault.message, fault_color(fault))
+            output(" [#{fault.test_name}]")
+            output(fault.location.first)
+          end
+
           def format_fault(fault)
             fault.long_display
           end
 
-          def test_started(name)
+          def output_statistics(elapsed_time)
+            output("Finished in #{elapsed_time} seconds.")
+            nl
+            output(@result, result_color)
+            output("%g%% passed" % @result.pass_percentage, result_color)
+            unless elapsed_time.zero?
+              nl
+              test_throughput = @result.run_count / elapsed_time
+              assertion_throughput = @result.assertion_count / elapsed_time
+              throughput = [
+                "%.2f tests/s" % test_throughput,
+                "%.2f assertions/s" % assertion_throughput,
+              ]
+              output(throughput.join(", "))
+            end
+          end
+
+          def test_started(test)
             return unless output?(VERBOSE)
 
-            name = name.sub(/\(.+?\)\z/, '')
+            name = test.name.sub(/\(.+?\)\z/, '')
             right_space = 8 * 2
             left_space = @progress_row_max - right_space
             left_space = left_space - indent.size - name.size
@@ -169,7 +309,7 @@ module Test
             @test_start = Time.now
           end
 
-          def test_finished(name)
+          def test_finished(test)
             unless @already_outputted
               output_progress(".", color("pass"))
             end
@@ -180,24 +320,24 @@ module Test
             output(": (%f)" % (Time.now - @test_start), nil, VERBOSE)
           end
 
-          def test_suite_started(name)
+          def test_suite_started(suite)
             if @top_level
               @top_level = false
               return
             end
 
             output_single(indent, nil, VERBOSE)
-            if /\A[A-Z]/ =~ name
-              _color = color("case")
-            else
+            if suite.test_case.nil?
               _color = color("suite")
+            else
+              _color = color("case")
             end
-            output_single(name, _color, VERBOSE)
+            output_single(suite.name, _color, VERBOSE)
             output(": ", nil, VERBOSE)
             @indent += 2
           end
 
-          def test_suite_finished(name)
+          def test_suite_finished(suite)
             @indent -= 2
           end
 
@@ -209,17 +349,17 @@ module Test
             end
           end
 
-          def nl(level=NORMAL)
+          def nl(level=nil)
             output("", nil, level)
           end
-          
-          def output(something, color=nil, level=NORMAL)
+
+          def output(something, color=nil, level=nil)
             return unless output?(level)
             output_single(something, color, level)
             @output.puts
           end
-          
-          def output_single(something, color=nil, level=NORMAL)
+
+          def output_single(something, color=nil, level=nil)
             return false unless output?(level)
             if @use_color and color
               something = "%s%s%s" % [color.escape_sequence,
@@ -242,8 +382,29 @@ module Test
             end
           end
 
+          def output_progress_in_detail_marker(fault)
+            if @progress_row_max > 0
+              output("=" * @progress_row_max, fault_color(fault))
+            else
+              nl
+            end
+          end
+
+          def output_progress_in_detail(fault)
+            return if @output_level == SILENT
+            nl
+            output_progress_in_detail_marker(fault)
+            if categorize_fault(fault) == :need_detail_faults
+              output_fault_in_detail(fault)
+            else
+              output_fault_in_short(fault)
+            end
+            output_progress_in_detail_marker(fault)
+            @progress_row = 0
+          end
+
           def output?(level)
-            level <= @output_level
+            (level || @current_output_level) <= @output_level
           end
 
           def color(name)
@@ -254,7 +415,11 @@ module Test
           end
 
           def fault_color(fault)
-            color(fault.class.name.split(/::/).last.downcase)
+            fault_class_color(fault.class)
+          end
+
+          def fault_class_color(fault_class)
+            color(fault_class.name.split(/::/).last.downcase)
           end
 
           def result_color
@@ -286,7 +451,7 @@ module Test
           end
 
           def guess_term_width
-            Integer(ENV["TERM_WIDTH"] || 0)
+            Integer(ENV["COLUMNS"] || ENV["TERM_WIDTH"] || 0)
           rescue ArgumentError
             0
           end
@@ -424,7 +589,3 @@ module Test
     end
   end
 end
-
-if __FILE__ == $0
-  Test::Unit::UI::Console::TestRunner.start_command_line_test
-end
