@@ -2075,15 +2075,16 @@ client_run_workers (MilterClient *client, guint n_workers, GError **error)
                     g_strerror(errno));
         return FALSE;
     }
-    priv->workers.control = setup_client_channel(pipe_fds[MILTER_UTILS_READ_PIPE]);
+
     for (i = 0; i < n_workers; ++i) {
         GPid pid = milter_client_fork(client);
         switch (pid) {
         case 0:
             close(pipe_fds[MILTER_UTILS_WRITE_PIPE]);
+            priv->workers.control = setup_client_channel(pipe_fds[MILTER_UTILS_READ_PIPE]);
             priv->workers.id = i + 1;
             milter_event_loop_watch_io(loop, priv->workers.control,
-                                       G_IO_IN | G_IO_PRI | G_IO_ERR,
+                                       G_IO_IN | G_IO_PRI | G_IO_ERR | G_IO_HUP,
                                        worker_watch_master, client);
             run_worker(client, error);
             milter_client_shutdown(client);
@@ -2097,12 +2098,12 @@ client_run_workers (MilterClient *client, guint n_workers, GError **error)
                         MILTER_CLIENT_ERROR_PROCESS,
                         "%s",
                         g_strerror(errno));
+            close(pipe_fds[MILTER_UTILS_READ_PIPE]);
             close(pipe_fds[MILTER_UTILS_WRITE_PIPE]);
-            g_io_channel_unref(priv->workers.control);
             return FALSE;
         }
     }
-    g_io_channel_unref(priv->workers.control);
+    close(pipe_fds[MILTER_UTILS_READ_PIPE]);
     priv->workers.control = setup_client_channel(pipe_fds[MILTER_UTILS_WRITE_PIPE]);
 
     milter_info("[client][workers][run] <%d>", n_workers);
@@ -2390,16 +2391,21 @@ run_worker (MilterClient *client, GError **error)
     priv->quitting = FALSE;
     loop = milter_client_get_event_loop(client);
     priv->accept_watch_id =
-        milter_event_loop_watch_io(loop,
-                                   priv->listening_channel,
-                                   G_IO_IN | G_IO_PRI,
-                                   worker_accept_watch_func, client);
+        milter_event_loop_watch_io_full(loop,
+                                        G_PRIORITY_HIGH,
+                                        priv->listening_channel,
+                                        G_IO_IN | G_IO_PRI,
+                                        worker_accept_watch_func,
+                                        client,
+                                        NULL);
     priv->accept_error_watch_id =
-        milter_event_loop_watch_io(loop,
-                                   priv->listening_channel,
-                                   G_IO_ERR | G_IO_HUP | G_IO_NVAL,
-                                   accept_error_watch_func,
-                                   client);
+        milter_event_loop_watch_io_full(loop,
+                                        G_PRIORITY_HIGH,
+                                        priv->listening_channel,
+                                        G_IO_ERR | G_IO_HUP | G_IO_NVAL,
+                                        accept_error_watch_func,
+                                        client,
+                                        NULL);
     milter_event_loop_run(loop);
 
     return TRUE;
