@@ -212,7 +212,7 @@ dispose (GObject *object)
     priv = MILTER_LIBEV_EVENT_LOOP_GET_PRIVATE(object);
 
     if (priv->watchers) {
-        g_hash_table_destroy(priv->watchers);
+        g_hash_table_unref(priv->watchers);
         priv->watchers = NULL;
     }
 
@@ -313,7 +313,20 @@ add_watcher (MilterLibevEventLoop *loop, ev_watcher *watcher,
     WatcherPrivate *watcher_priv;
 
     priv = MILTER_LIBEV_EVENT_LOOP_GET_PRIVATE(loop);
-    priv->id++;
+
+    while (TRUE) {
+        priv->id++;
+
+        if (priv->id == 0) {
+            continue;
+        }
+        if (g_hash_table_lookup_extended(priv->watchers,
+                                         GUINT_TO_POINTER(priv->id),
+                                         NULL, NULL)) {
+            continue;
+        }
+        break;
+    }
 
     watcher_priv = watcher->data;
     watcher_priv->loop = loop;
@@ -348,13 +361,13 @@ destroy_watcher (gpointer data)
     g_free(watcher);
 }
 
-static void
+static gboolean
 remove_watcher (MilterLibevEventLoop *loop, guint id)
 {
     MilterLibevEventLoopPrivate *priv;
 
     priv = MILTER_LIBEV_EVENT_LOOP_GET_PRIVATE(loop);
-    g_hash_table_remove(priv->watchers, GUINT_TO_POINTER(id));
+    return g_hash_table_remove(priv->watchers, GUINT_TO_POINTER(id));
 }
 
 static void
@@ -681,12 +694,7 @@ static gboolean
 remove (MilterEventLoop *loop,
         guint            id)
 {
-    gboolean success;
-    MilterLibevEventLoopPrivate *priv;
-
-    priv = MILTER_LIBEV_EVENT_LOOP_GET_PRIVATE(loop);
-    success = g_hash_table_remove(priv->watchers, GUINT_TO_POINTER(id));
-    return success;
+    return remove_watcher(MILTER_LIBEV_EVENT_LOOP(loop), id);
 }
 
 static void
