@@ -386,8 +386,12 @@ cut_teardown (void)
 static void
 pump_all_events (void)
 {
+    GError *error;
+
     milter_test_pump_all_events(loop);
-    gcut_assert_error(actual_error);
+    error = actual_error;
+    actual_error = NULL;
+    gcut_assert_error(error);
 }
 
 static GError *
@@ -397,6 +401,8 @@ feed (const gchar *packet, gsize packet_size)
 
     milter_client_context_feed(client_context, packet, packet_size, &error);
     if (!error) {
+        if (MILTER_IS_LIBEV_EVENT_LOOP(loop))
+            cut_omit("MilterLibevEventLoop doesn't support GCutStringIOChannel.");
         pump_all_events();
     }
 
